==> blancoCsv-1.1.3-src.zip: blancoCsv/blanco/main/blanco/sample/csv/record/BlancoCsvSampleCsvRecord.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.sample.csv.record;

import java.math.BigDecimal;
import java.util.Date;

/**
 * blancoCsvt@C`쐬ꂽR[hNX<br>
 * t@C`[BlancoCsvSample/̃NX͒PɃTvłBۂ̓ɂ͗p܂B]̃R[hNX
 */
public class BlancoCsvSampleCsvRecord {
    /**
     * tB[h [field_1]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   []<br>
     * ڔԍ: 1<br>
     * ڂ̐: tB[h1<br>
     * MIN: 1<br>
     * MAX: 10
     */
    private String fField1 = "";

    /**
     * tB[h [field_2]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [eXg]<br>
     * ڔԍ: 2<br>
     * ڂ̐: tB[h2<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 4<br>
     * MAX: 4
     */
    private String fField2 = "eXg";

    /**
     * tB[h [field_3]
     *
     * ڂ̌^ [java.lang.Integer]<br>
     * ڔԍ: 3<br>
     * ڂ̐: tB[h3<br>
     * MIN: 1<br>
     * MAX: 3
     */
    private Integer fField3;

    /**
     * tB[h [field_4]
     *
     * ڂ̌^ [java.lang.Long]<br>
     * Kl   [10]<br>
     * ڔԍ: 4<br>
     * ڂ̐: tB[h4<br>
     * MIN: 1<br>
     * MAX: 3
     */
    private Long fField4 = new Long(10);

    /**
     * tB[h [field_5]
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڔԍ: 5<br>
     * ڂ̐: tB[h5
     */
    private Date fField5;

    /**
     * tB[h [field_6]
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڔԍ: 6<br>
     * ڂ̐: tB[h6<br>
     * MIN: 1<br>
     * MAX: 3
     */
    private BigDecimal fField6;

    /**
     * tB[h [field_11]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڂ̐: tB[h11<br>
     * K{
     */
    private String fField11;

    /**
     * tB[h [field_12]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڂ̐: tB[h12<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     */
    private String fField12;

    /**
     * tB[h [field_13]
     *
     * ڂ̌^ [int]<br>
     * ڂ̐: tB[h13<br>
     * K{
     */
    private int fField13;

    /**
     * tB[h [field_14]
     *
     * ڂ̌^ [long]<br>
     * ڂ̐: tB[h14<br>
     * K{
     */
    private long fField14;

    /**
     * tB[h [field_15]
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڂ̐: tB[h15<br>
     * K{
     */
    private Date fField15;

    /**
     * tB[h [field_16]
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڂ̐: tB[h16<br>
     * K{
     */
    private BigDecimal fField16;

    /**
     * tB[h [field_1]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 1<br>
     * ڂ̐: tB[h1<br>
     * MIN: 1<br>
     * MAX: 10
     *
     * @param argField1 tB[h[field_1]Ɋi[l
     */
    public void setField1(final String argField1) {
        fField1 = argField1;
    }

    /**
     * tB[h[field_1]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   []<br>
     * ڔԍ: 1<br>
     * ڂ̐: tB[h1<br>
     * MIN: 1<br>
     * MAX: 10
     *
     * @return tB[h[field_1]Ɋi[Ăl
     */
    public String getField1() {
        return fField1;
    }

    /**
     * tB[h [field_2]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 2<br>
     * ڂ̐: tB[h2<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 4<br>
     * MAX: 4
     *
     * @param argField2 tB[h[field_2]Ɋi[l
     */
    public void setField2(final String argField2) {
        fField2 = argField2;
    }

    /**
     * tB[h[field_2]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [eXg]<br>
     * ڔԍ: 2<br>
     * ڂ̐: tB[h2<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 4<br>
     * MAX: 4
     *
     * @return tB[h[field_2]Ɋi[Ăl
     */
    public String getField2() {
        return fField2;
    }

    /**
     * tB[h [field_3]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.Integer]<br>
     * ڔԍ: 3<br>
     * ڂ̐: tB[h3<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @param argField3 tB[h[field_3]Ɋi[l
     */
    public void setField3(final Integer argField3) {
        fField3 = argField3;
    }

    /**
     * tB[h[field_3]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.Integer]<br>
     * ڔԍ: 3<br>
     * ڂ̐: tB[h3<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @return tB[h[field_3]Ɋi[Ăl
     */
    public Integer getField3() {
        return fField3;
    }

    /**
     * tB[h [field_4]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.Long]<br>
     * ڔԍ: 4<br>
     * ڂ̐: tB[h4<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @param argField4 tB[h[field_4]Ɋi[l
     */
    public void setField4(final Long argField4) {
        fField4 = argField4;
    }

    /**
     * tB[h[field_4]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.Long]<br>
     * Kl   [10]<br>
     * ڔԍ: 4<br>
     * ڂ̐: tB[h4<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @return tB[h[field_4]Ɋi[Ăl
     */
    public Long getField4() {
        return fField4;
    }

    /**
     * tB[h [field_5]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڔԍ: 5<br>
     * ڂ̐: tB[h5
     *
     * @param argField5 tB[h[field_5]Ɋi[l
     */
    public void setField5(final Date argField5) {
        fField5 = argField5;
    }

    /**
     * tB[h[field_5]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڔԍ: 5<br>
     * ڂ̐: tB[h5
     *
     * @return tB[h[field_5]Ɋi[Ăl
     */
    public Date getField5() {
        return fField5;
    }

    /**
     * tB[h [field_6]̃Zb^[\bh
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڔԍ: 6<br>
     * ڂ̐: tB[h6<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @param argField6 tB[h[field_6]Ɋi[l
     */
    public void setField6(final BigDecimal argField6) {
        fField6 = argField6;
    }

    /**
     * tB[h[field_6]̃Qb^[\bh
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڔԍ: 6<br>
     * ڂ̐: tB[h6<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @return tB[h[field_6]Ɋi[Ăl
     */
    public BigDecimal getField6() {
        return fField6;
    }

    /**
     * tB[h [field_11]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڂ̐: tB[h11<br>
     * K{
     *
     * @param argField11 tB[h[field_11]Ɋi[l
     */
    public void setField11(final String argField11) {
        fField11 = argField11;
    }

    /**
     * tB[h[field_11]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڂ̐: tB[h11<br>
     * K{
     *
     * @return tB[h[field_11]Ɋi[Ăl
     */
    public String getField11() {
        return fField11;
    }

    /**
     * tB[h [field_12]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڂ̐: tB[h12<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     *
     * @param argField12 tB[h[field_12]Ɋi[l
     */
    public void setField12(final String argField12) {
        fField12 = argField12;
    }

    /**
     * tB[h[field_12]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڂ̐: tB[h12<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     *
     * @return tB[h[field_12]Ɋi[Ăl
     */
    public String getField12() {
        return fField12;
    }

    /**
     * tB[h [field_13]̃Zb^[\bh
     *
     * ڂ̌^ [int]<br>
     * ڂ̐: tB[h13<br>
     * K{
     *
     * @param argField13 tB[h[field_13]Ɋi[l
     */
    public void setField13(final int argField13) {
        fField13 = argField13;
    }

    /**
     * tB[h[field_13]̃Qb^[\bh
     *
     * ڂ̌^ [int]<br>
     * ڂ̐: tB[h13<br>
     * K{
     *
     * @return tB[h[field_13]Ɋi[Ăl
     */
    public int getField13() {
        return fField13;
    }

    /**
     * tB[h [field_14]̃Zb^[\bh
     *
     * ڂ̌^ [long]<br>
     * ڂ̐: tB[h14<br>
     * K{
     *
     * @param argField14 tB[h[field_14]Ɋi[l
     */
    public void setField14(final long argField14) {
        fField14 = argField14;
    }

    /**
     * tB[h[field_14]̃Qb^[\bh
     *
     * ڂ̌^ [long]<br>
     * ڂ̐: tB[h14<br>
     * K{
     *
     * @return tB[h[field_14]Ɋi[Ăl
     */
    public long getField14() {
        return fField14;
    }

    /**
     * tB[h [field_15]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڂ̐: tB[h15<br>
     * K{
     *
     * @param argField15 tB[h[field_15]Ɋi[l
     */
    public void setField15(final Date argField15) {
        fField15 = argField15;
    }

    /**
     * tB[h[field_15]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڂ̐: tB[h15<br>
     * K{
     *
     * @return tB[h[field_15]Ɋi[Ăl
     */
    public Date getField15() {
        return fField15;
    }

    /**
     * tB[h [field_16]̃Zb^[\bh
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڂ̐: tB[h16<br>
     * K{
     *
     * @param argField16 tB[h[field_16]Ɋi[l
     */
    public void setField16(final BigDecimal argField16) {
        fField16 = argField16;
    }

    /**
     * tB[h[field_16]̃Qb^[\bh
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڂ̐: tB[h16<br>
     * K{
     *
     * @return tB[h[field_16]Ɋi[Ăl
     */
    public BigDecimal getField16() {
        return fField16;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.sample.csv.record.BlancoCsvSampleCsvRecord[");
        buf.append("field_1=" + fField1);
        buf.append(",field_2=" + fField2);
        buf.append(",field_3=" + fField3);
        buf.append(",field_4=" + fField4);
        buf.append(",field_5=" + fField5);
        buf.append(",field_6=" + fField6);
        buf.append(",field_11=" + fField11);
        buf.append(",field_12=" + fField12);
        buf.append(",field_13=" + fField13);
        buf.append(",field_14=" + fField14);
        buf.append(",field_15=" + fField15);
        buf.append(",field_16=" + fField16);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoCsv-1.2.1-src.zip: blancoCsv/blanco/main/blanco/sample/csv/record/BlancoCsvSampleCsvRecord.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.sample.csv.record;

import java.math.BigDecimal;
import java.util.Date;

/**
 * blancoCsvt@C`쐬ꂽR[hNX<br>
 * t@C`[BlancoCsvSample/̃NX͒PɃTvłBۂ̓ɂ͗p܂B]̃R[hNX
 */
public class BlancoCsvSampleCsvRecord {
    /**
     * tB[h [field_1]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   []<br>
     * ڔԍ: 1<br>
     * ڂ̐: tB[h1<br>
     * MIN: 1<br>
     * MAX: 10
     */
    private String fField1 = "";

    /**
     * tB[h [field_2]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [eXg]<br>
     * ڔԍ: 2<br>
     * ڂ̐: tB[h2<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 4<br>
     * MAX: 4
     */
    private String fField2 = "eXg";

    /**
     * tB[h [field_3]
     *
     * ڂ̌^ [java.lang.Integer]<br>
     * ڔԍ: 3<br>
     * ڂ̐: tB[h3<br>
     * MIN: 1<br>
     * MAX: 3
     */
    private Integer fField3;

    /**
     * tB[h [field_4]
     *
     * ڂ̌^ [java.lang.Long]<br>
     * Kl   [10]<br>
     * ڔԍ: 4<br>
     * ڂ̐: tB[h4<br>
     * MIN: 1<br>
     * MAX: 3
     */
    private Long fField4 = new Long(10);

    /**
     * tB[h [field_5]
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڔԍ: 5<br>
     * ڂ̐: tB[h5
     */
    private Date fField5;

    /**
     * tB[h [field_6]
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڔԍ: 6<br>
     * ڂ̐: tB[h6<br>
     * MIN: 1<br>
     * MAX: 3
     */
    private BigDecimal fField6;

    /**
     * tB[h [field_11]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 7<br>
     * ڂ̐: tB[h11<br>
     * K{
     */
    private String fField11;

    /**
     * tB[h [field_12]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 8<br>
     * ڂ̐: tB[h12<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     */
    private String fField12;

    /**
     * tB[h [field_13]
     *
     * ڂ̌^ [int]<br>
     * ڔԍ: 9<br>
     * ڂ̐: tB[h13<br>
     * K{
     */
    private int fField13;

    /**
     * tB[h [field_14]
     *
     * ڂ̌^ [long]<br>
     * ڔԍ: 10<br>
     * ڂ̐: tB[h14<br>
     * K{
     */
    private long fField14;

    /**
     * tB[h [field_15]
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڔԍ: 11<br>
     * ڂ̐: tB[h15<br>
     * K{
     */
    private Date fField15;

    /**
     * tB[h [field_16]
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڔԍ: 12<br>
     * ڂ̐: tB[h16<br>
     * K{
     */
    private BigDecimal fField16;

    /**
     * tB[h [field_1]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 1<br>
     * ڂ̐: tB[h1<br>
     * MIN: 1<br>
     * MAX: 10
     *
     * @param argField1 tB[h[field_1]Ɋi[l
     */
    public void setField1(final String argField1) {
        fField1 = argField1;
    }

    /**
     * tB[h[field_1]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   []<br>
     * ڔԍ: 1<br>
     * ڂ̐: tB[h1<br>
     * MIN: 1<br>
     * MAX: 10
     *
     * @return tB[h[field_1]Ɋi[Ăl
     */
    public String getField1() {
        return fField1;
    }

    /**
     * tB[h [field_2]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 2<br>
     * ڂ̐: tB[h2<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 4<br>
     * MAX: 4
     *
     * @param argField2 tB[h[field_2]Ɋi[l
     */
    public void setField2(final String argField2) {
        fField2 = argField2;
    }

    /**
     * tB[h[field_2]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [eXg]<br>
     * ڔԍ: 2<br>
     * ڂ̐: tB[h2<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 4<br>
     * MAX: 4
     *
     * @return tB[h[field_2]Ɋi[Ăl
     */
    public String getField2() {
        return fField2;
    }

    /**
     * tB[h [field_3]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.Integer]<br>
     * ڔԍ: 3<br>
     * ڂ̐: tB[h3<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @param argField3 tB[h[field_3]Ɋi[l
     */
    public void setField3(final Integer argField3) {
        fField3 = argField3;
    }

    /**
     * tB[h[field_3]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.Integer]<br>
     * ڔԍ: 3<br>
     * ڂ̐: tB[h3<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @return tB[h[field_3]Ɋi[Ăl
     */
    public Integer getField3() {
        return fField3;
    }

    /**
     * tB[h [field_4]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.Long]<br>
     * ڔԍ: 4<br>
     * ڂ̐: tB[h4<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @param argField4 tB[h[field_4]Ɋi[l
     */
    public void setField4(final Long argField4) {
        fField4 = argField4;
    }

    /**
     * tB[h[field_4]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.Long]<br>
     * Kl   [10]<br>
     * ڔԍ: 4<br>
     * ڂ̐: tB[h4<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @return tB[h[field_4]Ɋi[Ăl
     */
    public Long getField4() {
        return fField4;
    }

    /**
     * tB[h [field_5]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڔԍ: 5<br>
     * ڂ̐: tB[h5
     *
     * @param argField5 tB[h[field_5]Ɋi[l
     */
    public void setField5(final Date argField5) {
        fField5 = argField5;
    }

    /**
     * tB[h[field_5]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڔԍ: 5<br>
     * ڂ̐: tB[h5
     *
     * @return tB[h[field_5]Ɋi[Ăl
     */
    public Date getField5() {
        return fField5;
    }

    /**
     * tB[h [field_6]̃Zb^[\bh
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڔԍ: 6<br>
     * ڂ̐: tB[h6<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @param argField6 tB[h[field_6]Ɋi[l
     */
    public void setField6(final BigDecimal argField6) {
        fField6 = argField6;
    }

    /**
     * tB[h[field_6]̃Qb^[\bh
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڔԍ: 6<br>
     * ڂ̐: tB[h6<br>
     * MIN: 1<br>
     * MAX: 3
     *
     * @return tB[h[field_6]Ɋi[Ăl
     */
    public BigDecimal getField6() {
        return fField6;
    }

    /**
     * tB[h [field_11]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 7<br>
     * ڂ̐: tB[h11<br>
     * K{
     *
     * @param argField11 tB[h[field_11]Ɋi[l
     */
    public void setField11(final String argField11) {
        fField11 = argField11;
    }

    /**
     * tB[h[field_11]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 7<br>
     * ڂ̐: tB[h11<br>
     * K{
     *
     * @return tB[h[field_11]Ɋi[Ăl
     */
    public String getField11() {
        return fField11;
    }

    /**
     * tB[h [field_12]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 8<br>
     * ڂ̐: tB[h12<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     *
     * @param argField12 tB[h[field_12]Ɋi[l
     */
    public void setField12(final String argField12) {
        fField12 = argField12;
    }

    /**
     * tB[h[field_12]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 8<br>
     * ڂ̐: tB[h12<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     *
     * @return tB[h[field_12]Ɋi[Ăl
     */
    public String getField12() {
        return fField12;
    }

    /**
     * tB[h [field_13]̃Zb^[\bh
     *
     * ڂ̌^ [int]<br>
     * ڔԍ: 9<br>
     * ڂ̐: tB[h13<br>
     * K{
     *
     * @param argField13 tB[h[field_13]Ɋi[l
     */
    public void setField13(final int argField13) {
        fField13 = argField13;
    }

    /**
     * tB[h[field_13]̃Qb^[\bh
     *
     * ڂ̌^ [int]<br>
     * ڔԍ: 9<br>
     * ڂ̐: tB[h13<br>
     * K{
     *
     * @return tB[h[field_13]Ɋi[Ăl
     */
    public int getField13() {
        return fField13;
    }

    /**
     * tB[h [field_14]̃Zb^[\bh
     *
     * ڂ̌^ [long]<br>
     * ڔԍ: 10<br>
     * ڂ̐: tB[h14<br>
     * K{
     *
     * @param argField14 tB[h[field_14]Ɋi[l
     */
    public void setField14(final long argField14) {
        fField14 = argField14;
    }

    /**
     * tB[h[field_14]̃Qb^[\bh
     *
     * ڂ̌^ [long]<br>
     * ڔԍ: 10<br>
     * ڂ̐: tB[h14<br>
     * K{
     *
     * @return tB[h[field_14]Ɋi[Ăl
     */
    public long getField14() {
        return fField14;
    }

    /**
     * tB[h [field_15]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڔԍ: 11<br>
     * ڂ̐: tB[h15<br>
     * K{
     *
     * @param argField15 tB[h[field_15]Ɋi[l
     */
    public void setField15(final Date argField15) {
        fField15 = argField15;
    }

    /**
     * tB[h[field_15]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * ڔԍ: 11<br>
     * ڂ̐: tB[h15<br>
     * K{
     *
     * @return tB[h[field_15]Ɋi[Ăl
     */
    public Date getField15() {
        return fField15;
    }

    /**
     * tB[h [field_16]̃Zb^[\bh
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڔԍ: 12<br>
     * ڂ̐: tB[h16<br>
     * K{
     *
     * @param argField16 tB[h[field_16]Ɋi[l
     */
    public void setField16(final BigDecimal argField16) {
        fField16 = argField16;
    }

    /**
     * tB[h[field_16]̃Qb^[\bh
     *
     * ڂ̌^ [java.math.BigDecimal]<br>
     * ڔԍ: 12<br>
     * ڂ̐: tB[h16<br>
     * K{
     *
     * @return tB[h[field_16]Ɋi[Ăl
     */
    public BigDecimal getField16() {
        return fField16;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.sample.csv.record.BlancoCsvSampleCsvRecord[");
        buf.append("field_1=" + fField1);
        buf.append(",field_2=" + fField2);
        buf.append(",field_3=" + fField3);
        buf.append(",field_4=" + fField4);
        buf.append(",field_5=" + fField5);
        buf.append(",field_6=" + fField6);
        buf.append(",field_11=" + fField11);
        buf.append(",field_12=" + fField12);
        buf.append(",field_13=" + fField13);
        buf.append(",field_14=" + fField14);
        buf.append(",field_15=" + fField15);
        buf.append(",field_16=" + fField16);
        buf.append("]");
        return buf.toString();
    }
}
